@@ -4,9 +4,8 @@
 
 """
 
-__version__ = "1.0.22"
+__version__ = '1.0.13'
 
 from binance.client import Client, AsyncClient  # noqa
 from binance.depthcache import DepthCacheManager, OptionsDepthCacheManager, ThreadedDepthCacheManager  # noqa
-from binance.streams import BinanceSocketManager, ThreadedWebsocketManager, BinanceSocketType  # noqa
-from binance.enums import *  # noqa
\ No newline at end of file
+from binance.streams import BinanceSocketManager, ThreadedWebsocketManager  # noqa
